pub enum APIKeysAPIv2 {
AuthCloudPlatform,
AuthCloudPlatformReadOnly,
}Expand description
API Keys API, v2
Variants
AuthCloudPlatform
Documentation: See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account., Scope: https://www.googleapis.com/auth/cloud-platform
AuthCloudPlatformReadOnly
Documentation: View your data across Google Cloud services and see the email address of your Google Account, Scope: https://www.googleapis.com/auth/cloud-platform.read-only