pub enum BigQueryDataPolicyAPIv2 {
AuthBigquery,
AuthCloudPlatform,
}Expand description
BigQuery Data Policy API, v2
Variants
AuthBigquery
Documentation: View and manage your data in Google BigQuery and see the email address for your Google Account, Scope: https://www.googleapis.com/auth/bigquery
AuthCloudPlatform
Documentation: See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account., Scope: https://www.googleapis.com/auth/cloud-platform