pub enum FirebaseAppCheckAPIv1 {
AuthCloudPlatform,
AuthFirebase,
}Expand description
Firebase App Check API, v1
Variants
AuthCloudPlatform
Documentation: See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account., Scope: https://www.googleapis.com/auth/cloud-platform
AuthFirebase
Documentation: View and administer all your Firebase data and settings, Scope: https://www.googleapis.com/auth/firebase