pub enum FirebaseRealtimeDatabaseManagementAPIv1beta {
AuthCloudPlatform,
AuthCloudPlatformReadOnly,
AuthFirebase,
AuthFirebaseReadOnly,
}Expand description
Firebase Realtime Database Management API, v1beta
Variants
AuthCloudPlatform
Documentation: See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account., Scope: https://www.googleapis.com/auth/cloud-platform
AuthCloudPlatformReadOnly
Documentation: View your data across Google Cloud services and see the email address of your Google Account, Scope: https://www.googleapis.com/auth/cloud-platform.read-only
AuthFirebase
Documentation: View and administer all your Firebase data and settings, Scope: https://www.googleapis.com/auth/firebase
AuthFirebaseReadOnly
Documentation: View all your Firebase data and settings, Scope: https://www.googleapis.com/auth/firebase.readonly