pub enum ServiceControlAPIv2 {
AuthCloudPlatform,
AuthServicecontrol,
}Expand description
Service Control API, v2
Variants
AuthCloudPlatform
Documentation: See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account., Scope: https://www.googleapis.com/auth/cloud-platform
AuthServicecontrol
Documentation: Manage your Google Service Control data, Scope: https://www.googleapis.com/auth/servicecontrol